# Qt Style

This is the ftrack integrations qt-style library.
All style and resource files for qt used in the ftrack integrations products should be found here.

### Manual build

Go to the root of the Monorepo and build the ftrack style resource.py:

```bash
  cd integrations
  pip install -r tools/requirements.txt
  python tools/build.py build_qt_resources libs/qt-style
```
